@@ -8,6 +8,7 @@ our $VERSION = '0.07';
 # shortcuts
 use constant os_freebsd  => (os => 'freebsd');
 use constant os_windows  => (os => 'MSWin32');
+use constant os_darwin   => (os => 'darwin'); # really means installer=homebrew
 use constant like_debian => (linuxdistro => '~debian');
 
 sub mapping {
@@ -26,6 +27,11 @@ sub mapping {
        [package => 'g++']],
      ],
 
+     ## Does not help, tests still fail (Alien-Electron-0.102):
+     #[cpanmod => 'Alien::Electron',
+     # [like_debian,
+     #  [package => 'libnotify4']]],
+
      [cpanmod => 'Alien::ffmpeg',
       [os_freebsd,
        [package => 'yasm']],
@@ -269,6 +275,9 @@ sub mapping {
        # this one does not work with Compress::LZMA::Simple under debian
        [package => 'liblzma-dev']]],
 
+     # Try also the patches listed in
+     # https://rt.cpan.org/Ticket/Display.html?id=86115
+     # (or the corresponding srezic-cpan-distroprefs file)
      [cpanmod => 'Compress::LZO',
       [os_freebsd,
        [package => 'lzo2']],
@@ -522,7 +531,9 @@ sub mapping {
       [like_debian,
        [linuxdistrocodename => ['precise'],
 	[package => 'libgd-noxpm-dev | libgd2-xpm-dev']],
-       [package => 'libgd-dev']]],
+       [package => 'libgd-dev']],
+      [os_darwin,
+       [package => 'libgd']]],
 
      [cpanmod => 'Gearman::XS',
       [os_freebsd,
@@ -754,6 +765,12 @@ sub mapping {
       [like_debian,
        [package => ['libcv-dev', 'libhighgui-dev']]]],
 
+     [cpanmod => 'Image::Scale',
+      [os_freebsd,
+       [package => [qw(png jpeg)]]],
+      [like_debian,
+       [package => [qw(libjpeg-dev libpng12-dev)]]]],
+
      [cpanmod => 'Image::SubImageFind',
       # XXX what about freebsd?
       [like_debian,
@@ -766,6 +783,8 @@ sub mapping {
        [linuxdistrocodename => 'wheezy',
 	[package => [qw(libfreetype6-dev libgif-dev libpng12-dev libjpeg-dev), 'libtiff5-dev | libtiff4-dev']]],
        [package => [qw(libfreetype6-dev libgif-dev libpng12-dev libjpeg-dev libtiff5-dev)]]],
+      [os_darwin,
+       [package => [qw(freetype giflib libpng jpeg libtiff)]]],
      ],
 
      [cpanmod => 'Imager::Font::T1',
@@ -1248,7 +1267,7 @@ sub mapping {
        ],
        [package => 'couchdb']]],
 
-     [cpanmod => 'SVN::Hooks', # XXX maybe more SVN::* modules?
+     [cpanmod => ['SVN::Hooks', 'SVN::Agent'], # XXX maybe more SVN::* modules?
       [package => 'subversion']],
 
      [cpanmod => 'Sword',
@@ -1387,6 +1406,11 @@ sub mapping {
 	[package => 'libtiff4-dev']],
        [package => 'libtiff5-dev']]],
 
+     [cpanmod => 'Tk::Zinc',
+      # XXX freebsd?
+      [like_debian,
+       [package => ['mesa-common-dev', 'libglu1-mesa-dev']]]],
+
      [cpanmod => 'UDT::Simple',
       [os_freebsd,
        [package => 'udt']],
